#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import yaml
sys.path.insert(1, 'csdownscale/')
from tools import cut_domain 
from utils import get_domain,get_ldmonths,load_lpconf,load_fxconf,get_fcst,get_hcst,get_obs,apply_analogs

def main(run_conf,run_sdate):
    """ Main program """

    with open(run_conf) as f: 
        doc = yaml.load(f)  

    doc["loop_params"]["sdates"] = [run_sdate] 
    run_conf = f"logs/{run_sdate}-vitigeoos-seasonal.yml"

    with open(run_conf,"w") as f: 
        yaml.dump(doc,f,default_flow_style=False) 

    loop_prms = load_lpconf(run_conf)
    fx_prms = load_fxconf(run_conf)
    arch_conf = fx_prms['arch_conf']
    regions = loop_prms['regions']
    fcst_sdates = loop_prms['sdates']
    target_vars = loop_prms['target_vars']
    ld_times = fx_prms['ld_months']

    apply_to = fx_prms["apply_to"] 

    for target_var in target_vars:

        # load obs
        print(f'target_var:{target_var}')
        print('loading obs for analogs training...')
        targetobs, srcobs = get_obs(run_conf,arch_conf, target_var)
        print('lazy load completed...')

        for region in regions:

            print(f'region:{region}')

            # cut obs
            print('cutting domain and loading obs data in memory...')    
            srcobs_sub = cut_domain(srcobs,get_domain(region,arch_conf)).load()
            targetobs_sub = cut_domain(targetobs,get_domain(region,arch_conf)).load()
            print('obs load completed...')    


            for fcst_sdate in fcst_sdates:

                ld_months = get_ldmonths(ld_times[0],fcst_sdate[4:6])
                print(f'fcst start date:{fcst_sdate}')

                # load exp
                if apply_to == "all" or apply_to == "hcst":

                    exp = get_hcst(run_conf,arch_conf,region,fcst_sdate,ld_months,target_var)
                    apply_analogs(exp,srcobs_sub,targetobs_sub,run_conf,arch_conf,target_var,region)

                if apply_to == "all" or apply_to == "fcst":
                    fcst = get_fcst(run_conf,arch_conf,region,fcst_sdate,ld_months,target_var)
                    apply_analogs(fcst,srcobs_sub,targetobs_sub,run_conf,arch_conf,target_var,region)
 
if __name__ == "__main__":

    run_conf = sys.argv[1] 
    #run_conf = "conf/vitigeoos-seasonal-run.yml"
    run_sdate = sys.argv[2]
    #run_sdate = "20210701"

    main(run_conf,run_sdate)

 